@@ -10,6 +10,12 @@ import os
 import sys
 import logging
 
+FORMAT = (
+    '\x1b[?77h$COLOR%(asctime)s $BOLD$COLOR%(name)s '
+    '$RESET%(message)s at $BOLD$COLOR%(funcName)s:%(lineno)d$RESET\x1b[?77l')
+FORMAT = os.getenv('LOG_COLORIZER_FORMAT', FORMAT)
+
+
 if sys.platform == 'win32':
     try:
         import colorama
@@ -47,7 +53,7 @@ class ColorFormatter(logging.Formatter):
 
 
 def make_colored_stream_handler(
-        std=sys.stdout, level=logging.DEBUG):
+        std=sys.stdout, level=logging.DEBUG, format=FORMAT):
     """Return a colored stream handler"""
     handler = logging.StreamHandler(std)
     handler.setLevel(level)
@@ -57,10 +63,7 @@ def make_colored_stream_handler(
         fn = None
 
     if fn is None or os.isatty(fn):
-        handler.setFormatter(
-            ColorFormatter(
-                '$COLOR%(asctime)s $BOLD$COLOR%(name)s'
-                ' %(funcName)s:%(lineno)d $RESET %(message)s'))
+        handler.setFormatter(ColorFormatter(format))
     return handler
 
 
@@ -69,13 +72,26 @@ def get_color_logger(name=None, silent=False, **kwargs):
     logger = logging.getLogger(name)
     handler = make_colored_stream_handler(**kwargs)
     logger.addHandler(handler)
+    logger.propagate = False
     if not silent:
         logger.setLevel(logging.DEBUG)
     return logger
 
 
-def colorize():
-    logging._defaultFormatter = ColorFormatter(
-        '$COLOR%(asctime)s $BOLD$COLOR%(name)s'
-        ' %(funcName)s:%(lineno)d $RESET %(message)s')
+def colorize(format=FORMAT):
+    colorize_default_formatter(format)
     logging.root.handlers = [make_colored_stream_handler()]
+
+
+def basicConfig(**kwargs):
+    handler = make_colored_stream_handler()
+    if kwargs.get('handlers'):
+        kwargs['handlers'].append(handler)
+    else:
+        kwargs['handlers'] = [handler]
+
+    return logging.basicConfig(**kwargs)
+
+
+def colorize_default_formatter(format=FORMAT):
+    logging._defaultFormatter = ColorFormatter(format)
